# trendalation

An anomaly detection package for all sorts of trends & time series data. The library leverages algorithms like procrustes analysis to compare and contrast the general shape & trajectory of different trends.

```insert images here```

## Installation

### Dependencies

trendalation requires:

Python (>= 3.8)
NumPy (>= 1.25.0)
Scikit-Learn (>=1.3.0)
SciPy (>= 1.11.1)

### Using pip

The easiest way to install trendalation is using pip:
`pip install trendalation`

## Documentation

## Help and Support

In order to report bugfixes and new feature requests, simply create a new issue on the repository.
The issues will be reviewed by the authors on a regular basis & you're welcome to work on any open issues.

## Contribution

This project is a community effort, and everyone is welcome to contribute.
Feel free to work on any open issues and setup PRs.
